#
# spec file for package python-rstcheck
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-rstcheck
Version:        6.2.5
Release:        1.1
Summary:        Python module to check syntax of reStructuredText
License:        MIT
URL:            https://github.com/rstcheck/rstcheck
Source:         https://files.pythonhosted.org/packages/source/r/rstcheck/rstcheck-%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rstcheck-core >= 1.2}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module typer >= 0.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  bash
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-rstcheck-core >= 1.2
Requires:       python-typer >= 0.4.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     bash
Recommends:     gcc
Recommends:     gcc-c++
Recommends:     python-Sphinx
Provides:       rstcheck = %{version}
Obsoletes:      rstcheck < %{version}
BuildArch:      noarch
%python_subpackages

%description
A Python module to check the syntax of reStructuredText and code
blocks nested within it.

%prep
%autosetup -p1 -n rstcheck-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/rstcheck
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%post
%python_install_alternative rstcheck

%postun
%python_uninstall_alternative rstcheck

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%python_alternative %{_bindir}/rstcheck
%{python_sitelib}/rstcheck
%{python_sitelib}/rstcheck-%{version}.dist-info

%changelog
* Wed Jun  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.2.5:
  * Dropped support for python 3.8
  * Added python 3.13 to tox config.
  * Dropped support for sphinx 5
  * Add sphinx 8 to test pool for python version > 3.9
- Drop patch support-click-8.2.patch, included upstream.
- Update URL.
* Wed May 21 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-click-8.2.patch:
  * Support click 8.2 changes.
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 6.2.4:
  * Add note on how to disable pretty exception output
  * Fix typer dependency by removing the `[standard]` extra which
    is only used on typer-slim.
  * Typer by default has the extras included.
  * Bump min. version of typer and fix dependency group name
  * Update configs for dev tooling
  * Bump default python version to 3.12
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 6.2.1:
  * Remove unused pre python 3.8 compatibility code
  * Drop support for sphinx v4
  * Added `__main__.py` to enable command-line execution via
    python -m rstcheck
* Thu Mar  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.2.0:
  * Fix bug where variable in log string was not substituted
  * Drop support for Sphinx v2 and v3
  * Switch from poetry to setuptools
  * Set tomli extra dependency to python < 3.11 like rstcheck-core
  * Drop python 3.7
  * **MOVED THE CORE LIBRARY INTO IT'S OWN REPOSITORY**
  * `rstcheck.config.load_config_file_from_path` now raises an
    FileNotFoundError if the given path is neither a file nor a directory
  * Add `NONE` as a special config file path, to disable config file loading
  * Catch SyntaxWarnings in python code-blocks and handle them like
    SyntaxErrors
  * Add additional inline configuration and flow control options
  * `find_ignored_languages` no longer throws exception but logs warning
  * Add `--log-level` option to CLI
  * Add `--warn-unknown-settings` flag to CLI
  * String lists for `ignore_*` configs are white-space cleaned at string
    start and end.
  * Add support for INI multi-line string back
  * Full restructuring of the code base
  * Rewrite of CLI with `typer`
  * Renamed config `report` to `report_level`
  * Renamed config `ignore_language` to `ignore_languages`
  * Renamed CLI option `--report` to `--report-level`
  * Renamed CLI option `--ignore-language` to `--ignore-languages`
  * Drop CLI option `--ignore` as alias to `--ignore-languages`
  * Drop CLI option `--debug`
  * Drop default values for directives and roles for sphinx
  * CLI options now take precedence over config file options
  * Add section with `Known limitations / FAQ` to the README
  * Accumulate all errors in rst source instead of only one
  * Allow errors in code blocks to be ignored via ignore_messages
  * Add support for TOML config files
  * Fix inability to ignore `code`, `code-block` and `sourcecode` directives
  * Fix `code-block` options recognition
  * Fix Malformed tables because of substitutions
  * Fix: remove `include` directive from ignore list when sphinx is active
  * Add examples/ to sdist
  * Rewrite old test suite in pytest and AAA style
  * Fix shebangs and scripts to use `python3` instead of `python`
  * Improve the gcc checker functions by removing restrictions and
    using environment variable flags
  * Drop support for python versions prior 3.7
  * Add `--config` option to change the location of the config file.
- No longer download the tarball from GitHub, the tests are shipped.
- Switch to pyproject, autosetup and pytest macros.
- Drop patch test-path.patch, no longer needed.
- No more greedy globs in %%files.
* Wed Feb 10 2021 Markéta Machová <mmachova@suse.com>
- Get rid of %%ifpython3
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable testing in this package:
  * The tests deadlock in 2 out of 10 builds
  * Upstream needs to provide proper testing before we can enable
    it here
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Add LANG=en_US.UTF-8 to %%check to fix Leap test failures
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide/Obsolete the rstcheck which was python3 named version
  only already present in TW
* Thu Feb 14 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Wed Feb 13 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond_with test
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Add recommends for the checkers rstcheck supports
- Remove unnecessary build dependency python-devel
- Activate tests
- Update to v3.3.1
  * Make compatible with Sphinx >= 1.8.
- from 3.3
  * Parse more options from configuration file (thanks to Santos Gallegos).
  * Allow ignoring specific (info/warning/error) messages via
    ``--ignore-messages`` (thanks to Santos Gallegos).
- from 3.2
  * Check for invalid Markdown-style links (thanks to biscuitsnake).
  * Allow configuration to be stored in ``setup.cfg`` (thanks to Maël Pedretti).
  * Add ``--recursive`` option to recursively drill down directories to check for
    all ``*.rst`` files.
- Use %%license
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
